#!/usr/bin/python

import os.path
import sys

from client import encrypt_path
from security.cryptography import rsa_encrypt
from security.profile import get_current_profile
from rpc.client import RPCClient

def main(hostname, port, username, path, permission):
    prof = get_current_profile()
    pieces = path.split(os.path.sep)
    pieces[0] = os.path.sep
    for ndx, piece in enumerate(pieces):
        path_so_far = os.path.join(*pieces[:ndx+1])
        ndx_key = prof.get_key_for_file(path_so_far)
        pubkey = prof.rsa_get_user_pubkey(username)
        user_key_info_encrypted = prof.rsa_encrypt_user_key_info(path=path_so_far, key=ndx_key, pubkey=pubkey)
        pieces_aes_encrypted = encrypt_path(path_so_far)
        if ndx < len(pieces) - 1:
            permission_to_grant = 'minread'
        else:
            permission_to_grant = permission
        rpc_client = RPCClient(hostname, port)
        rpc_client.make_rpc_call('grant_permission_to_user', username, permission_to_grant,
                                 pieces_aes_encrypted, user_key_info_encrypted)

if __name__ == "__main__":
    hostname = sys.argv[1]
    port = int(sys.argv[2])
    username = sys.argv[3]
    path = sys.argv[4]
    permission = sys.argv[5]                             
    main(hostname, port, username, path, permission)
