import os

from cryptography import rsa_verify, RSA_DUMMY_KEY
from sql_backend import SQLBackend

CRYPT_FS_DIR = os.path.join(os.environ['HOME'], '.cryptfs')

class UserKeyStore(SQLBackend):
    """
    A key store object representing a *server's* store of users' keys.
    """
    def __init__(self):
        SQLBackend.__init__(self, os.path.join(CRYPT_FS_DIR, 'keystore.sql'))

    def init_db(self):
        SQLBackend.init_db(self)
        self.execute_query("CREATE TABLE user_rsa_pubkeys (username TEXT PRIMARY KEY, rsa_pubkey TEXT)")

    def register_user(self, username, rsa_pubkey):
        rows = self.execute_query("SELECT * FROM user_rsa_pubkeys WHERE username=?", (username,))
        if len(rows) == 0:
            # need to insert
            self.execute_query("INSERT INTO user_rsa_pubkeys (username, rsa_pubkey) VALUES (?, ?)", (username, rsa_pubkey))
        else:
            # need to update
            self.execute_query("UPDATE user_rsa_pubkeys SET rsa_pubkey=? WHERE username=?", (rsa_pubkey, username))

    def get_rsa_pubkey(self, username):
        rows = self.execute_query("SELECT rsa_pubkey FROM user_rsa_pubkeys WHERE username=?", (username,))
        try:
            rsa_pubkey = rows[0][0]
            return rsa_pubkey
        except IndexError:
            return RSA_DUMMY_KEY

    def rsa_verify_signature(self, message, signature, username):
        pubkey = self.get_rsa_pubkey(username)
        return rsa_verify(message, signature, pubkey)
