import os

from sql_backend import SQLBackend
from permission import Permission, PERMISSION_NONE

CRYPT_FS_DIR = os.path.join(os.environ['HOME'], '.cryptfs')

class UserPermissionStore(SQLBackend):
    """
    A permission store object representing a *server's* store of file permissions.
    """
    def __init__(self):
        SQLBackend.__init__(self, os.path.join(CRYPT_FS_DIR, 'permissionstore.sql'))

    def init_db(self):
        SQLBackend.init_db(self)
        self.execute_query("CREATE TABLE user_permission_store (username TEXT, path TEXT, permission TEXT, user_encrypted_key_info TEXT)")

    def grant_permission_to_user(self, username, permission_to_grant, path, user_encrypted_key_info):
        rows = self.execute_query("SELECT permission FROM user_permission_store WHERE username=? AND path=? LIMIT 1", (username, path))
        if len(rows) == 0:
            # need to insert
            if permission_to_grant.startswith('min'):
                permission_to_grant = permission_to_grant[3:]
            self.execute_query("INSERT INTO user_permission_store (username, path, permission, user_encrypted_key_info) VALUES (?, ?, ?, ?)", (username, path, permission_to_grant, user_encrypted_key_info))
        else:
            curr_permission = Permission(rows[0][0])
            if permission_to_grant.startswith('min'):
                intended = Permission(permission_to_grant[3:])
                if curr_permission < intended:
                    permission_to_grant = intended.perm
                else:
                    permission_to_grant = curr_permission.perm
            elif permission_to_grant.startswith('max'):
                intended = Permission(permission_to_grant[3:])
                if curr_permission > intended:
                    permission_to_grant = intended.perm
                else:
                    permission_to_grant = curr_permission.perm
            # need to update
            self.execute_query("UPDATE user_permission_store SET permission=?, user_encrypted_key_info=? WHERE username=? AND path=?", (permission_to_grant, user_encrypted_key_info, username, path))

    def get_permission_for_user(self, username, path):
	rows = self.execute_query("SELECT permission FROM user_permission_store WHERE username=? AND path=? LIMIT 1", (username, path))
	if len(rows) == 0:
	    return PERMISSION_NONE
	else:
	    return Permission(rows[0][0])
    
    def get_key_info_for_path(self, username, path):
        rows = self.execute_query("SELECT user_encrypted_key_info FROM user_permission_store WHERE username=? AND path=? LIMIT 1", (username, path))
        if len(rows) > 0:
            key_info = rows[0][0]
            return key_info
        else:
            return None

    def delete_key(self, path, username):
        self.execute_query("DELETE FROM user_permission_store WHERE username=? AND path=?", (username, path))
