import os
import sqlite3

class SQLBackend(object):
    """
    A profile object representing a *client's* profile (which is just
    a set of keys).
    """
    def __init__(self, db_path):
        self.db_path = db_path
        if not os.path.exists(self.db_path):
            self.init_db()

    def init_db(self):
        containing_directory = os.path.dirname(self.db_path)
        if not os.path.exists(containing_directory):
            os.mkdir(containing_directory)
        self.reload_sql_db()

    def make_new_conn(self):
        return sqlite3.connect(self.db_path)

    def reload_sql_db(self):
        conn = self.make_new_conn()
        conn.close()

    def execute_query(self, query, args=None):
        if args is None:
            args = tuple()
        with self.make_new_conn() as conn:
            cursor = conn.cursor()
            cursor.execute(query, args)
            conn.commit()
            return list(cursor.fetchall())

